package simulation;

import java.util.*;

class State extends GlobalSimulation {
	public int numberInQueue = 0, accumulated = 0, noMeasurements = 0;
	private EventList eventList;

	State(EventList eventList) {
		this.eventList = eventList;
	}

	// Dispatches the events to the right handler
	public void TreatEvent(Event x) {
		if (x.eventType == ARRIVAL)
			arrival();
		else if (x.eventType == READY)
			ready();
		else if (x.eventType == MEASURE)
			measure();
	}

	// Helper to generate a random number with certain statistical properties
	private static double generateMean(double mean) {
		return 2 * mean * rand.nextDouble();
	}

	private void arrival() {
		if (numberInQueue == 0)
			eventList.insertEvent(new Event(READY, time + generateMean(1)));
		numberInQueue++;
		eventList.insertEvent(new Event(ARRIVAL, time + generateMean(2)));
	}

	private void ready() {
		numberInQueue--;
		if (numberInQueue > 0)
			eventList.insertEvent(new Event(READY, time + generateMean(1)));
	}

	private void measure() {
		accumulated = accumulated + numberInQueue;
		noMeasurements++;
		eventList.insertEvent(new Event(MEASURE, time + generateMean(5)));
	}
}